@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.014-8-g92325ba
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.015-13-g171a56a
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 use Moose;
 with
@@ -238,6 +238,7 @@ my %sub_dependencies = (
     can_xs => [ qw(can_cc) ],
     can_cc => [ qw(can_run) ],
     can_run => [ qw(maybe_command) ],
+    requires => [ qw(runtime_requires) ],
 );
 
 has _all_required_subs => (
@@ -247,15 +248,15 @@ has _all_required_subs => (
     lazy => 1,
     default => sub {
         my $self = shift;
-        my @conditions = $self->conditions;
-        my @subs_in_conditions = !@conditions ? () :
+        my @code = ($self->conditions, $self->raw);
+        my @subs_in_code = !@code ? () :
             grep {
                 my $sub_name = $_;
-                any { $_ =~ /$sub_name/ } @conditions
+                any { /\b$sub_name\b\(/ } @code
             } map { $_->basename } path($self->_include_sub_root)->children;
 
         [ sort($self->_all_required_subs_for(_uniq(
-            $self->include_subs, @subs_in_conditions
+            $self->include_subs, @subs_in_code,
         ))) ];
     },
 );
@@ -307,7 +308,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -317,13 +318,13 @@ In your F<dist.ini>:
     -condition = has_module('Role::Tiny')
     -condition = !parse_args()->{PUREPERL_ONLY}
     -condition = can_xs()
-    -raw = $WriteMakefileArgs{PREREQ_PM}{'Role::Tiny'} = $FallbackPrereqs{'Role::Tiny'} = '1.003000'
+    -raw = requires('Role::Tiny', '1.003000')
 
 or:
 
     [DynamicPrereqs]
     -delimiter = |
-    -raw = |$WriteMakefileArgs{TEST_REQUIRES}{'Devel::Cover'} = $FallbackPrereqs{'Devel::Cover'} = '0'
+    -raw = |test_requires('Devel::Cover')
     -raw = |    if $ENV{EXTENDED_TESTING} or is_smoker();
     -include_sub = is_smoker
 
@@ -357,6 +358,15 @@ Only F<Makefile.PL> modification is supported at this time. This author
 considers the use of L<Module::Build> to be questionable in all circumstances,
 and L<Module::Build::Tiny> does not (yet?) support dynamic configuration.
 
+=head1 BE VIGILANT!
+
+You are urged to check the generated F<Makefile.PL> for sanity, and to run it
+at least once to validate its syntax. Although every effort is made to
+generate valid and correct code, mistakes can happen, so verification is
+needed before shipping.
+
+Please also see the other warnings later in this document.
+
 =head1 CONFIGURATION OPTIONS
 
 =head2 C<-raw>
@@ -369,11 +379,6 @@ L<Dist::Zilla::Plugin::MakeMaker::Awesome> since L<Dist::Zilla> C<5.001>.
 
 This option can be used more than once; lines are added in the order in which they are provided.
 
-This option is pretty low-level; I anticipate its use to be deprecated when
-better options are added (see below). In particular, the user should not have
-to be aware of existing code in F<Makefile.PL> nor the exact code required to
-add prerequisites of various types.
-
 If you use external libraries in the code you are inserting, you B<must> add
 these modules to C<configure_requires> prereqs in metadata (e.g. via
 C<[Prereqs / ConfigureRequires]> in your F<dist.ini>).
@@ -416,27 +421,27 @@ statement, and the C<-raw> lines are contained as the body of the block. For exa
 
     [DynamicPrereqs]
     -condition = $] > '5.020'
-    -raw = $WriteMakefileArgs{PREREQ_PM}{'Role::Tiny'} = $FallbackPrereqs{'Role::Tiny'} = '1.003000'
+    -raw = requires('1.003000')
 
 results in the F<Makefile.PL> snippet:
 
     if ($] > '5.020') {
-    $WriteMakefileArgs{PREREQ_PM}{'Role::Tiny'} = $FallbackPrereqs{'Role::Tiny'} = '1.003000'
+    requires('Role::Tiny', '1.003000')
     }
 
 =head2 C<-include_sub>
 
-(Available since version 0.010; some subs have been added later, as noted)
-
-The name of a subroutine that you intend to call from the code inserted via
-C<-raw> or C<-raw_from_file>. Its definition will be included in
-F<Makefile.PL>, as well as any helper subs it calls; necessary prerequisite
-modules will be added to C<configure requires> metadata.
-This option can be used more than once. See L</AVAILABLE SUBROUTINE
-DEFINITIONS> for the complete list of sub names that can be requested.
+(Available since version 0.010; rendered unnecessary in 0.016 (all definitions
+are now included automatically, when used).
 
 =head1 AVAILABLE SUBROUTINE DEFINITIONS
 
+A number of helper subroutines are available for use within your code inserted
+via C<-raw>, C<-raw_from_file>, or C<-condition> clauses. When used, their
+definition(s) will be included automatically in F<Makefile.PL> (as well as
+those of any other subroutines I<they> call).
+
+Unless otherwise noted, these all became available in version 0.010.
 Available subs are:
 
 =over 4
@@ -497,6 +502,22 @@ C<isnt_os($os, ...)> - true if the OS is none of those listed
 
 C<maybe_command> - actually a monkeypatch to C<< MM->maybe_command >> (please keep using the fully-qualified form) to work in Cygwin
 
+=item *
+
+C<runtime_requires($module, $version (optional))> - adds the module to runtime prereqs (as a shorthand for editing the hashes in F<Makefile.PL> directly). Added in 0.016.
+
+=item *
+
+C<requires($module, $version (optional))> - alias for C<runtime_requires>. Added in 0.016.
+
+=item *
+
+C<build_requires($module, $version (optional))> - adds the module to runtime prereqs (as a shorthand for editing the hashes in F<Makefile.PL> directly). Added in 0.016.
+
+=item *
+
+C<test_requires($module, $version (optional))> - adds the module to runtime prereqs (as a shorthand for editing the hashes in F<Makefile.PL> directly). Added in 0.016.
+
 =back
 
 =head1 WARNING: INCOMPLETE SUBROUTINE IMPLEMENTATIONS!
@@ -542,14 +563,6 @@ C<-build> a module and version that is added to build prereqs should the C<-cond
 
 =back
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-DynamicPrereqs>
-(or L<bug-Dist-Zilla-Plugin-DynamicPrereqs@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-DynamicPrereqs@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -576,6 +589,19 @@ L<Module::Install::Can>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-DynamicPrereqs>
+(or L<bug-Dist-Zilla-Plugin-DynamicPrereqs@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-DynamicPrereqs@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+http://dzil.org/#mailing-list.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
